@@ -24,7 +24,7 @@ trans_abund <- R6Class(classname = "trans_abund",
 		#' @param prefix default NULL; character string; available when \code{delete_taxonomy_prefix = T}; 
 		#'   default NULL represents using the "letter+__", e.g. "k__" for Phylum level;
 		#'   Please provide the customized prefix when it is not standard, otherwise the program can not correctly recognize it.
-		#' @param use_percentage default TRUE; show the abundance percentage.
+		#' @param use_percentage default TRUE; whether show the abundance percentage. If TRUE, the abundance data will be multiplied by 100.
 		#' @param input_taxaname default NULL; character vector; input taxa names to select some taxa.
 		#' @param high_level default NULL; a taxonomic rank, such as "Phylum", used to add the taxonomic information of higher level.
 		#'   It is required for the legend with nested taxonomic levels in the bar plot or the higher taxonomic level in facets of y axis in the heatmap.
@@ -114,9 +114,12 @@ trans_abund <- R6Class(classname = "trans_abund",
 					if(identical(high_level, taxrank)){
 						stop("Provided high_level should not be same with taxrank !")
 					}
-					extract_tax_table <- dataset$tax_table[, c(high_level, taxrank)] %>% unique
-					if(!delete_taxonomy_lineage){
-						stop("The delete_taxonomy_lineage should be TRUE when high_level is provided!")
+					if(delete_taxonomy_lineage){
+						extract_tax_table <- dataset$tax_table[, c(high_level, taxrank)] %>% unique
+					}else{
+						tmp_tax_table <- dataset$tax_table
+						tmp_tax_table[, taxrank] <- apply(tmp_tax_table[, 1:match(taxrank, colnames(tmp_tax_table))], 1, function(x){paste0(x, collapse = "|")})
+						extract_tax_table <- tmp_tax_table[, c(high_level, taxrank)] %>% unique
 					}
 					if(delete_taxonomy_prefix){
 						extract_tax_table[, taxrank] %<>% gsub(prefix, "", .)
@@ -188,7 +191,6 @@ trans_abund <- R6Class(classname = "trans_abund",
 		#' @param color_values default \code{RColorBrewer::brewer.pal}(8, "Dark2"); colors palette for the bars.
 		#' @param bar_full default TRUE; Whether the bar shows all the features (including 'Others'). 
 		#'    Default \code{TRUE} means total abundance are summed to 1 or 100 (percentage). \code{FALSE} means 'Others' will not be shown.
-		#' @param bar_type deprecated. Please use \code{bar_full} argument instead.
 		#' @param others_color default "grey90"; the color for "Others" taxa.
 		#' @param facet default NULL; a character vector for the facet; group column name of \code{sample_table}, such as, \code{"Group"};
 		#'    If multiple facets are needed, please provide ordered names, such as \code{c("Group", "Type")}.
@@ -217,6 +219,7 @@ trans_abund <- R6Class(classname = "trans_abund",
 		#'   To make it available, please assign \code{high_level} parameter when creating the object.
 		#' @param high_level_add_other default FALSE; whether add 'Others' (all the unknown taxa) in each taxon of higher taxonomic level.
 		#'   Only available when \code{ggnested = TRUE}.
+		#' @param bar_type deprecated. Please use \code{bar_full} argument instead.
 		#' @return ggplot2 object. 
 		#' @examples
 		#' \donttest{
@@ -225,7 +228,6 @@ trans_abund <- R6Class(classname = "trans_abund",
 		plot_bar = function(
 			color_values = RColorBrewer::brewer.pal(8, "Dark2"),
 			bar_full = TRUE,
-			bar_type = deprecated(),
 			others_color = "grey90",
 			facet = NULL,
 			order_x = NULL,
@@ -245,7 +247,8 @@ trans_abund <- R6Class(classname = "trans_abund",
 			ytitle_size = 17,
 			coord_flip = FALSE,
 			ggnested = FALSE,
-			high_level_add_other = FALSE
+			high_level_add_other = FALSE,
+			bar_type = deprecated()
 			){
 			
 			if(lifecycle::is_present(bar_type)) {
